@@ -6,3 +6,9 @@ get_taxa_order <- function(tree_view) {
     })
 }
 
+
+theme_no_margin <- function(...) {
+    ggplot2::theme(plot.margin = ggplot2::margin(), ...)
+}
+
+
